<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 новое сообщение</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 минут назад</translation>
    </message>
</context>
</TS>